@@ -22,8 +22,7 @@
 #define __XFDESKTOP_FILE_ICON_MANAGER_H__
 
 #include <glib.h>
-
-#include <thunar-vfs/thunar-vfs.h>
+#include <xfconf/xfconf.h>
 
 #include "xfdesktop-special-file-icon.h"
 #include "xfdesktop-icon-view-manager.h"
@@ -51,9 +50,10 @@ struct _XfdesktopFileIconManagerClass
     GObjectClass parent;
 };
 
-GType xfdesktop_file_icon_manager_get_type() G_GNUC_CONST;
+GType xfdesktop_file_icon_manager_get_type(void) G_GNUC_CONST;
 
-XfdesktopIconViewManager *xfdesktop_file_icon_manager_new(ThunarVfsPath *folder);
+XfdesktopIconViewManager *xfdesktop_file_icon_manager_new(GFile *folder,
+                                                          XfconfChannel *channel);
 
 void xfdesktop_file_icon_manager_set_show_removable_media(XfdesktopFileIconManager *manager,
                                                           gboolean show_removable_media);
@@ -64,6 +64,15 @@ void xfdesktop_file_icon_manager_set_show_special_file(XfdesktopFileIconManager
                                                        gboolean show_special_file);
 gboolean xfdesktop_file_icon_manager_get_show_special_file(XfdesktopFileIconManager *manager,
                                                            XfdesktopSpecialFileIconType type);
+void xfdesktop_file_icon_manager_set_show_thumbnails(XfdesktopFileIconManager *manager,
+                                                     gboolean show_thumbnails);
+gboolean xfdesktop_file_icon_manager_get_show_thumbnails(XfdesktopFileIconManager *manager);
+
+gboolean xfdesktop_file_icon_manager_get_cached_icon_position(
+                                                    XfdesktopFileIconManager *fmanager,
+                                                    const gchar *name,
+                                                    gint16 *row,
+                                                    gint16 *col);
 
 G_END_DECLS
 
